/*jshint browser:true */
/*!
 * FitVids 1.1
 *
 * Copyright 2013, Chris Coyier - http://css-tricks.com + Dave Rupert - http://daverupert.com
 * Credit to Thierry Koblentz - http://www.alistapart.com/articles/creating-intrinsic-ratios-for-video/
 * Released under the WTFPL license - http://sam.zoy.org/wtfpl/
 *
 */

;
(function($) {

	'use strict';

	$.fn.fitVids = function(options) {
		var settings = {
			customSelector: null,
			ignore: null
		};

		if (!document.getElementById('fit-vids-style')) {
			// appendStyles: https://github.com/toddmotto/fluidvids/blob/master/dist/fluidvids.js
			var head = document.head || document.getElementsByTagName('head')[0];
			var css = '.fluid-width-video-wrapper{width:100%;position:relative;padding:0;}.fluid-width-video-wrapper iframe,.fluid-width-video-wrapper object,.fluid-width-video-wrapper embed {position:absolute;top:0;left:0;width:100%;height:100%;}';
			var div = document.createElement("div");
			div.innerHTML = '<p>x</p><style id="fit-vids-style">' + css + '</style>';
			head.appendChild(div.childNodes[1]);
		}

		if (options) {
			$.extend(settings, options);
		}

		return this.each(function() {
			var selectors = [
				'iframe[src*="player.vimeo.com"]',
				'iframe[src*="youtube.com"]',
				'iframe[src*="youtube-nocookie.com"]',
				'iframe[src*="kickstarter.com"][src*="video.html"]',
				'object',
				'embed'
			];

			if (settings.customSelector) {
				selectors.push(settings.customSelector);
			}

			var ignoreList = '.fitvidsignore';

			if (settings.ignore) {
				ignoreList = ignoreList + ', ' + settings.ignore;
			}

			var $allVideos = $(this).find(selectors.join(','));
			$allVideos = $allVideos.not('object object'); // SwfObj conflict patch
			$allVideos = $allVideos.not(ignoreList); // Disable FitVids on this video.

			$allVideos.each(function() {
				var $this = $(this);
				if ($this.parents(ignoreList).length > 0) {
					return; // Disable FitVids on this video.
				}
				if (this.tagName.toLowerCase() === 'embed' && $this.parent('object').length || $this.parent('.fluid-width-video-wrapper').length) {
					return;
				}
				if ((!$this.css('height') && !$this.css('width')) && (isNaN($this.attr('height')) || isNaN($this.attr('width')))) {
					$this.attr('height', 9);
					$this.attr('width', 16);
				}
				var height = (this.tagName.toLowerCase() === 'object' || ($this.attr('height') && !isNaN(parseInt($this.attr('height'), 10)))) ? parseInt($this.attr('height'), 10) : $this.height(),
					width = !isNaN(parseInt($this.attr('width'), 10)) ? parseInt($this.attr('width'), 10) : $this.width(),
					aspectRatio = height / width;
				if (!$this.attr('name')) {
					var videoName = 'fitvid' + $.fn.fitVids._count;
					$this.attr('name', videoName);
					$.fn.fitVids._count++;
				}
				$this.wrap('<div class="fluid-width-video-wrapper"></div>').parent('.fluid-width-video-wrapper').css('padding-top', (aspectRatio * 100) + '%');
				$this.removeAttr('height').removeAttr('width');
			});
		});
	};

	// Internal counter for unique video names.
	$.fn.fitVids._count = 0;

	// Works with either jQuery or Zepto
})(window.jQuery || window.Zepto);

(function($) {

	"use strict";

	var ww = window.innerWidth,
		wh = window.innerHeight;

	var grid = {

		init: function() {
			grid.adjust();
		},

		adjust: function() {
			var container = $('.gallery');

			for (var i = 0; i < container.length; i++) {
				// container
				var active_container = $(container[i]);

				// cols
				var cols = parseInt(active_container.data('cols'), 10);

				if (ww >= 1024) {
					if (!cols) cols = 3;
				} else if (ww > 800) {
					if (cols !== 1) cols = 2;
				} else {
					cols = 1;
				}

				// margin
				var margin = parseInt(active_container.data('margin'), 10);
				if (!margin) margin = 0;

				if (ww < 550) {
					if (margin > 15)
						margin = 15;
				}

				// set margin to the container
				if (active_container.hasClass('full')) {
					active_container.css('padding', Math.floor(margin / 2));
				} else {
					active_container.css('margin', -Math.floor(margin / 2));
				}

				// ratio
				var ratio = active_container.data('ratio'),
					aspect;

				switch (ratio) {
					case '4:3':
						aspect = 1.333;
						break;
					case '16:9':
						aspect = 1.777;
						break;
					case '1:1':
						aspect = 1;
						break;
					case '3:4':
						aspect = 0.75;
						break;
				}

				// container width
				var container_width = active_container.width();

				// items
				var items = active_container.find('.entry'),
					items_width = Math.floor((container_width / cols) - margin),
					items_height = Math.floor(items_width / aspect),
					items_double_height = Math.floor(items_height * 2),
					items_margin = Math.floor(margin / 2);

				items.each(function() {
					$(this).css('width', items_width);
					$(this).css('margin', items_margin);
					$(this).css('overflow', 'hidden');

					$(this).find('.entry__content').css({
						'position': 'absolute',
						'top': 0,
						'right': 0,
						'bottom': 0,
						'left': 0,
						'z-index': 1
					});

					if (items_height)
						$(this).css('height', items_height);

					if ($(this).hasClass('h2') && ww > 800)
						$(this).css('height', items_double_height + margin);

					if ($(this).hasClass('w2') && ww > 800 && cols != 1)
						$(this).css('width', items_width * 2 + margin);

					if ($(this).hasClass('fw'))
						$(this).css('width', container_width - margin);

					if ($(this).hasClass('fh') && ww > 800)
						$(this).css('height', wh);
				});

				// isotope
				active_container.isotope({
					itemSelector: '.entry',
					masonry: {
						columnWidth: items_width + margin
					}
				});

				$('.filters li').on('click', function() {
					var filter = $(this).data('filter');

					$('.filters li').removeClass('active');
					$(this).addClass('active');

					active_container.isotope({
						filter: filter
					});
				});

				// crazy offset
				if (ww < 800) {
					if (active_container.hasClass('offset')) {
						active_container.removeClass('offset').addClass('has-offset');
					}
				} else {
					if (active_container.hasClass('has-offset')) {
						active_container.removeClass('has-offset').addClass('offset');
					}
				}
			};
		}

	}

	$(window).on('load', function() {
		grid.init();
	});

	$(window).on('resize', function() {
		ww = window.innerWidth;
		wh = window.innerHeight;

		grid.init();
	});

})(jQuery);
