<?php

// FastWP Framework - menu

namespace fastwp_sima_core;

// Do not allow directly accessing this file.
if ( ! defined( 'ABSPATH' ) ) {
	die( 'Direct script access denied.' );
}

class menu_admin {

    public static function custom_nav_fields( $menu_item ) {
        $menu_item->menutype = get_post_meta( $menu_item->ID, '_menu_item_menutype', true );
        return $menu_item;
    }

    public static function update_custom_fields( $menu_id, $menu_item_id, $args  ) {
        if( isset( $_REQUEST['menu-item-menutype'][$menu_item_id] ) ) {
            $menutypeclass_value = $_REQUEST['menu-item-menutype'][$menu_item_id];
            update_post_meta( $menu_item_id, '_menu_item_menutype', $menutypeclass_value );
        }
    }

    public static function edit_walker( $walker, $menu_id ) {
        return 'fastwp_sima_core\FastwpSimaWalkerNavMenuEditCustom';
    }

}

// Init filters & actions

add_filter( 'wp_setup_nav_menu_item', array( 'fastwp_sima_core\menu_admin', 'custom_nav_fields' ) );
add_action( 'wp_update_nav_menu_item', array( 'fastwp_sima_core\menu_admin', 'update_custom_fields' ), 10, 3 );
add_filter( 'wp_edit_nav_menu_walker', array( 'fastwp_sima_core\menu_admin', 'edit_walker' ), 10, 2 );


/*** Modify the original walker ***/

class FastwpSimaWalkerNavMenuEditCustom extends \Walker_Nav_Menu {
	function start_lvl( &$output, $depth = 0, $args = array() ) {}

	function end_lvl( &$output, $depth = 0, $args = array() ) {}

	function start_el( &$output, $item, $depth = 0, $args = array() , $current_object_id = 0 ) {
        global $_wp_nav_menu_max_depth;

	    $_wp_nav_menu_max_depth = $depth > $_wp_nav_menu_max_depth ? $depth : $_wp_nav_menu_max_depth;

	    $indent = ( $depth ) ? str_repeat( "\t", $depth ) : '';

	    ob_start();
	    $item_id = esc_attr( $item->ID );
	    $removed_args = array();

	    $original_title = '';
	    if ( 'taxonomy' == $item->type ) {
	        $original_title = get_term_field( 'name', $item->object_id, $item->object, 'raw' );
	        if ( is_wp_error( $original_title ) )
	            $original_title = false;
	    } elseif ( 'post_type' == $item->type ) {
	        $original_object = get_post( $item->object_id );
	        $original_title = $original_object->post_title;
	    }

	    $classes = array(
	        'menu-item menu-item-depth-' . $depth,
	        'menu-item-' . esc_attr( $item->object ),
	        'menu-item-edit-' . ( ( isset( $_GET['edit-menu-item'] ) && $item_id == $_GET['edit-menu-item'] ) ? 'active' : 'inactive'),
	    );

	    $title = $item->title;

	    if ( ! empty( $item->_invalid ) ) {
	        $classes[] = 'menu-item-invalid';
	        /* translators: %s: title of menu item which is invalid */
	        $title = sprintf( esc_html__( '%s (Invalid)' , 'sima' ), $item->title );
	    } elseif ( isset( $item->post_status ) && 'draft' == $item->post_status ) {
	        $classes[] = 'pending';
	        /* translators: %s: title of menu item in draft status */
	        $title = sprintf( esc_html__('%s (Pending)' , 'sima' ), $item->title );
	    }

	    $title = empty( $item->label ) ? $title : $item->label; ?>
	    <li id="menu-item-<?php echo esc_attr( $item_id ); ?>" class="<?php echo esc_attr( implode( ' ', $classes ) ); ?>">
	        <dl class="menu-item-bar">
	            <dt class="menu-item-handle">
	                <span class="item-title"><?php echo esc_html( $title ); ?></span>
	                <span class="item-controls">
	                    <span class="item-type"><?php echo esc_html( $item->type_label ); ?></span>
	                    <span class="item-order hide-if-js">
	                        <a href="<?php echo wp_nonce_url(
	                                add_query_arg(
	                                    array(
	                                        'action' => 'move-up-menu-item',
	                                        'menu-item' => $item_id,
	                                    ),
	                                    remove_query_arg($removed_args, admin_url( 'nav-menus.php' ) )
	                                ),
	                                'move-menu_item'
	                            );  ?>" class="item-move-up"><abbr title="<?php esc_attr_e( 'Move up' , 'sima' ); ?>">&#8593;</abbr></a>
	                        |
	                        <a href="<?php echo wp_nonce_url(
	                                add_query_arg(
	                                    array(
	                                        'action' => 'move-down-menu-item',
	                                        'menu-item' => $item_id,
	                                    ),
	                                    remove_query_arg( $removed_args, admin_url( 'nav-menus.php' ) )
	                                ),
	                                'move-menu_item'
	                            ); ?>" class="item-move-down"><abbr title="<?php esc_attr_e( 'Move down', 'sima' ); ?>">&#8595;</abbr></a>
	                    </span>
	                    <a class="item-edit" id="edit-<?php echo esc_attr( $item_id ); ?>" title="<?php esc_attr_e('Edit Menu Item' , 'sima' ); ?>" href="<?php
	                        echo ( isset( $_GET['edit-menu-item'] ) && $item_id == $_GET['edit-menu-item'] ) ? admin_url( 'nav-menus.php' ) : add_query_arg( 'edit-menu-item', $item_id, remove_query_arg( $removed_args, admin_url( 'nav-menus.php#menu-item-settings-' . $item_id ) ) );
	                    ?>"><?php esc_html_e( 'Edit Menu Item' , 'sima' ); ?></a>
	                </span>
	            </dt>
	        </dl>

	        <div class="menu-item-settings" id="menu-item-settings-<?php echo esc_attr( $item_id ); ?>">

	            <?php if( 'custom' == $item->type ) : ?>
	                <p class="field-url description description-wide">
	                    <label for="edit-menu-item-url-<?php echo esc_attr( $item_id ); ?>">
	                        <?php esc_html_e( 'URL' , 'sima' ); ?><br />
	                        <input type="text" id="edit-menu-item-url-<?php echo esc_attr( $item_id ); ?>" class="widefat code edit-menu-item-url" name="menu-item-url[<?php echo esc_attr( $item_id ); ?>]" value="<?php echo esc_attr( $item->url ); ?>" />
	                    </label>
	                </p>
	            <?php endif; ?>
	            <p class="description description-thin">
	                <label for="edit-menu-item-title-<?php echo esc_attr( $item_id ); ?>">
	                    <?php esc_html_e( 'Navigation Label' , 'sima' ); ?><br />
	                    <input type="text" id="edit-menu-item-title-<?php echo esc_attr( $item_id ); ?>" class="widefat edit-menu-item-title" name="menu-item-title[<?php echo esc_attr( $item_id ); ?>]" value="<?php echo esc_attr( $item->title ); ?>" />
	                </label>
	            </p>
	            <p class="description description-thin">
	                <label for="edit-menu-item-attr-title-<?php echo esc_attr( $item_id ); ?>">
	                    <?php esc_html_e( 'Title Attribute' , 'sima' ); ?><br />
	                    <input type="text" id="edit-menu-item-attr-title-<?php echo esc_attr( $item_id ); ?>" class="widefat edit-menu-item-attr-title" name="menu-item-attr-title[<?php echo esc_attr( $item_id ); ?>]" value="<?php echo esc_attr( $item->post_excerpt ); ?>" />
	                </label>
	            </p>
	            <p class="field-link-target description">
	                <label for="edit-menu-item-target-<?php echo esc_attr( $item_id ); ?>">
	                    <input type="checkbox" id="edit-menu-item-target-<?php echo esc_attr( $item_id ); ?>" value="_blank" name="menu-item-target[<?php echo esc_attr( $item_id ); ?>]"<?php checked( $item->target, '_blank' ); ?> />
	                    <?php esc_html_e( 'Open link in a new window/tab' , 'sima' ); ?>
	                </label>
	            </p>
                <?php if( esc_attr( $item->menu_item_parent ) == 0 ) { ?>
                <p class="field-custom description description-wide fastwp-edit-menu-type">
	                <label for="edit-menu-item-menutype-<?php echo esc_attr( $item_id ); ?>">
						<?php esc_html_e( 'Menu Type' , 'sima' ); ?><br />
                        <select class="widefat" id="edit-menu-item-menutype-<?php echo esc_attr( $item_id ); ?>" name="menu-item-menutype[<?php echo esc_attr( $item_id ); ?>]">
                            <option value="page" <?php selected( 'page' , esc_attr( $item->menutype ) , true ); ?>><?php esc_html_e( 'Normal Page' , 'sima'); ?></option>
                            <option value="mega2" <?php selected( 'mega2' , esc_attr( $item->menutype ) , true ); ?>><?php esc_html_e( 'Mega Menu - 2 cols' , 'sima'); ?></option>
                            <option value="mega3" <?php selected( 'mega3' , esc_attr( $item->menutype ) , true ); ?>><?php esc_html_e( 'Mega Menu - 3 cols' , 'sima'); ?></option>
                            <option value="mega4" <?php selected( 'mega4' , esc_attr( $item->menutype ) , true ); ?>><?php esc_html_e( 'Mega Menu - 4 cols' , 'sima'); ?></option>
                        </select>
	                </label>
	            </p>
                <?php } ?>
	            <p class="field-xfn description description-thin">
	                <label for="edit-menu-item-xfn-<?php echo esc_attr( $item_id ); ?>">
	                    <?php esc_html_e( 'Link Relationship (XFN)' , 'sima' ); ?><br />
	                    <input type="text" id="edit-menu-item-xfn-<?php echo esc_attr( $item_id ); ?>" class="widefat code edit-menu-item-xfn" name="menu-item-xfn[<?php echo esc_attr( $item_id ); ?>]" value="<?php echo esc_attr( $item->xfn ); ?>" />
	                </label>
	            </p>
	            <p class="field-css-classes description description-thin">
	                <label for="edit-menu-item-classes-<?php echo esc_attr($item_id); ?>">
	                    <?php esc_html_e( 'CSS Classes (optional)' , 'sima' ); ?><br />
	                    <input type="text" id="edit-menu-item-classes-<?php echo esc_attr($item_id); ?>" class="widefat code edit-menu-item-classes" name="menu-item-classes[<?php echo esc_attr($item_id); ?>]" value="<?php echo esc_attr( implode(' ', $item->classes ) ); ?>" />
	                </label>
	            </p>
	            <p class="field-description description description-wide">
	                <label for="edit-menu-item-description-<?php echo esc_attr( $item_id ); ?>">
	                    <?php esc_html_e( 'Description' , 'sima' ); ?><br />
	                    <textarea id="edit-menu-item-description-<?php echo esc_attr( $item_id ); ?>" class="widefat edit-menu-item-description" rows="3" cols="20" name="menu-item-description[<?php echo esc_attr( $item_id ); ?>]"><?php echo esc_html( $item->description ); // textarea_escaped ?></textarea>
	                    <span class="description"><?php esc_html_e( 'The description will be displayed in the menu if the current theme supports it.' , 'sima' ); ?></span>
	                </label>
	            </p>
	            <p class="field-move hide-if-no-js description description-wide">
					<label>
						<span><?php esc_html_e( 'Move', 'sima' ); ?></span>
						<a href="#" class="menus-move-up" title="<?php esc_attr_e( 'Move up one', 'sima' ); ?>" style="display: inline;"><?php esc_html_e( 'Up one', 'sima' ); ?></a>
						<a href="#" class="menus-move-down" title="<?php esc_attr_e( 'Move down one', 'sima' ); ?>" style="display: inline;"><?php esc_html_e( 'Down one', 'sima' ); ?></a>
						<a href="#" class="menus-move-left" style="display: none;"></a>
						<a href="#" class="menus-move-right" title="<?php esc_attr_e( 'Move under Home', 'sima' ); ?>" style="display: inline;"><?php esc_html_e( 'Under Home', 'sima' ); ?></a>
						<a href="#" class="menus-move-top" title="<?php esc_attr_e( 'Move to the top', 'sima' ); ?>" style="display: inline;"><?php esc_html_e( 'To The Top', 'sima' ); ?></a>
					</label>
				</p>
	            <div class="menu-item-actions description-wide submitbox">
	                <?php if( 'custom' != $item->type && $original_title !== false ) : ?>
	                    <p class="link-to-original">
	                        <?php printf( esc_html__( 'Original: %s' , 'sima' ), '<a href="' . esc_url( $item->url ) . '">' . esc_html( $original_title ) . '</a>' ); ?>
	                    </p>
	                <?php endif; ?>
	                <a class="item-delete submitdelete deletion" id="delete-<?php echo esc_attr( $item_id ); ?>" href="<?php
	                echo wp_nonce_url( add_query_arg( array(
                            'action' => 'delete-menu-item',
                            'menu-item' => $item_id,
                        ), remove_query_arg($removed_args, admin_url( 'nav-menus.php' ) )
                    ), 'delete-menu_item_' . $item_id
	                ); ?>"><?php esc_html_e('Remove' , 'sima'); ?></a> <span class="meta-sep"> | </span> <a class="item-cancel submitcancel" id="cancel-<?php echo esc_attr( $item_id ); ?>" href="<?php echo esc_url( add_query_arg( array('edit-menu-item' => $item_id, 'cancel' => time()), remove_query_arg( $removed_args, admin_url( 'nav-menus.php' ) ) ) );
	                    ?>#menu-item-settings-<?php echo esc_attr( $item_id ); ?>"><?php esc_html_e( 'Cancel' , 'sima' ); ?></a>
	            </div>

	            <input class="menu-item-data-db-id" type="hidden" name="menu-item-db-id[<?php echo esc_attr( $item_id ); ?>]" value="<?php echo esc_attr( $item_id ); ?>" />
	            <input class="menu-item-data-object-id" type="hidden" name="menu-item-object-id[<?php echo esc_attr( $item_id ); ?>]" value="<?php echo esc_attr( $item->object_id ); ?>" />
	            <input class="menu-item-data-object" type="hidden" name="menu-item-object[<?php echo esc_attr( $item_id ); ?>]" value="<?php echo esc_attr( $item->object ); ?>" />
	            <input class="menu-item-data-parent-id" type="hidden" name="menu-item-parent-id[<?php echo esc_attr( $item_id ); ?>]" value="<?php echo esc_attr( $item->menu_item_parent ); ?>" />
	            <input class="menu-item-data-position" type="hidden" name="menu-item-position[<?php echo esc_attr( $item_id ); ?>]" value="<?php echo esc_attr( $item->menu_order ); ?>" />
	            <input class="menu-item-data-type" type="hidden" name="menu-item-type[<?php echo esc_attr( $item_id ); ?>]" value="<?php echo esc_attr( $item->type ); ?>" />
	        </div><!-- .menu-item-settings-->
	        <ul class="menu-item-transport"></ul>
            </li>

	    <?php $output .= ob_get_clean();
	}
}
