<?php

// FastWP Framework - Redux

namespace fastwp_sima_core;

// Do not allow directly accessing this file.
if ( ! defined( 'ABSPATH' ) ) {
	die( 'Direct script access denied.' );
}

class redux {

    private $sections = array();
    private $args = array();

    function __construct() {

        if( !class_exists( 'ReduxFramework' ) ) {
            return;
        }

        // Just for demo purposes. Not needed per say.
        $this->theme = wp_get_theme();

        // Set the default arguments
        $this->setArguments();


        // Create the sections and fields
        $this->getSections();

        if ( !isset( $this->args['opt_name'] ) ) { // No errors please
            return;
        }

        $this->ReduxFramework = new \ReduxFramework($this->sections, $this->args);

    }

    public function getSections() {

        $this->sections[] = array(
            'icon'      => 'el-icon-wrench',
            'title'     => esc_html__('General', 'sima'),
            'fields'    => array(
                array(
                    'id'        => 'opt-info-field',
                    'type'      => 'info',
                    'title'     => esc_html__( 'Welcome to Sima Options Panel.', 'sima' ),
                    'desc'      => esc_html__( 'It is meant to make your life easier by offering you options which will customize your website. Here you can set all general options that affects entire website.', 'sima' )
                ),
                array(
                    'id'        => 'custom_logo_light',
                    'type'      => 'media',
                    'title'     => esc_html__( 'Custom Logo for Light Menu', 'sima' ),
                ),
                array(
                    'id'        => 'menu_color',
                    'type'      => 'select',
                    'title'     => esc_html__( 'Menu Color', 'sima' ),
                    'options'   => array(
                                        'black' => esc_html__( 'Black', 'sima' ),
                                        'light' => esc_html__( 'Light', 'sima' )
                                        )
                ),
                array(
                    'id'        => 'fwp_smoothscroll',
                    'type'      => 'switch',
                    'title'     => esc_html__( 'Smooth Scroll', 'sima' ),
                    'on'        => 'Yes',
                    'off'       => 'No',
                    'default'   => false,
                ),
                array(
                    'id'        => 'info_bubble_1_text',
                    'type'      => 'editor',
                    'required'  => array( 'use_info_bubble_1', '=', '1' ),
                    'title'     => esc_html__( 'Info bubble #1 content', 'sima' ),
                    'subtitle'  => esc_html__( 'Place here your info bubble content.', 'sima' )
                ),
                array(
                    'id'        => 'fwp_custom_js',
                    'type'      => 'ace_editor',
                    'title'     => esc_html__( 'Custom JS', 'sima' ),
                    'subtitle'  => esc_html__( 'Paste your JavaScript code here. Use this field to quickly add JS code snippets.', 'sima' ),
                    'mode'      => 'javascript',
                    'theme'     => 'chrome',
                    'default'   => ""
                ),
                array(
                    'id'        => 'fwp_gmap_key',
                    'type'      => 'text',
                    'title'     => esc_html__( 'Google Maps API Key', 'sima' ),
                    'subtitle'  => esc_html__( 'How to generate your api key ? Video: https://www.youtube.com/watch?v=-UCHsqxBqwY', 'sima' ),
                )
            )
        );

        $this->sections[] = array(
            'icon'      => 'el-icon-lines',
            'title'     => esc_html__('Menu', 'sima'),
            'fields'    => array(
                array(
                    'id'        => 'menu_contact_info',
                    'type'      => 'textarea',
                    'title'     => esc_html__( 'Contact info', 'sima' )
                )
            )
        );

        $this->sections[] = array(
            'icon'      => 'el el-fast-forward',
            'title'     => esc_html__( 'Preloader Options', 'sima' ),
            'fields'    => array(
                array(
                    'id'        => 'show_preloader',
                    'type'      => 'switch',
                    'title'     => esc_html__( 'Show preloader', 'sima' ),
                    'subtitle'  => esc_html__( 'Enable/Disable preloader.', 'sima' ),
                    'default'   => 1,
                    'on'        => 'Enabled',
                    'off'       => 'Disabled'
                ),
            )

        );

        $this->sections[] = array(
            'icon'      => 'el-icon-th-list',
            'title'     => esc_html__( 'Blog', 'sima' ),
            'fields'    => array(
                array(
                    'id'        => 'fwp_hide_blog_title',
                    'type'      => 'switch',
                    'title'     => esc_html__( 'Hide Blog Title', 'sima' ),
                    'subtitle'  => esc_html__( 'Shows or hides the blog title.', 'sima' ),
                    'on'        => 'Yes',
                    'off'       => 'No',
                    'default'   => false,
                ),
                array(
                    'id'        => 'fwp_blog_minititle',
                    'type'      => 'text',
                    'title'     => esc_html__( 'Blog Mini Title', 'sima' ),
                    'subtitle'  => esc_html__( 'Blog Mini Title', 'sima' ),
                    'default'   => 'Blog',
                ),
                array(
                    'id'        => 'fwp_blog_title',
                    'type'      => 'text',
                    'title'     => esc_html__( 'Blog Title', 'sima' ),
                    'subtitle'  => esc_html__( 'Blog title', 'sima' ),
                    'default'   => 'Blog Title Here'
                ),
                array(
                    'id'        => 'fwp_blog_date_meta',
                    'type'      => 'switch',
                    'title'     => esc_html__( 'Hide Date Info', 'sima' ),
                    'subtitle'  => esc_html__( 'Shows or hides the date information on single.', 'sima' ),
                    'on'        => 'Yes',
                    'off'       => 'No',
                    'default'   => false,
                ),
                array(
                    'id'        => 'fwp_blog_sidebar',
                    'type'      => 'select',
                    'title'     => esc_html__( 'Show Sidebar', 'sima' ),
                    'options'   => array(
                                        ''      => esc_html__( 'No sidebar', 'sima' ),
                                        'left'  => esc_html__( 'Left sidebar', 'sima' ),
                                        'right' => esc_html__( 'Right sidebar', 'sima' ),
                                        )
                ),
                array(
                    'id'        => 'fwp_blog_bg',
                    'type'      => 'media',
                    'title'     => esc_html__( 'Image Background', 'sima' ),
                )
            )
        );

        $this->sections[] = array(
            'icon'      => 'el-icon-th-list',
            'title'     => esc_html__( 'Blog Single', 'sima' ),
            'fields'    => array(
                array(
                    'id'        => 'fwp_blog_sidebar_single',
                    'type'      => 'select',
                    'title'     => esc_html__( 'Show Sidebar on Single', 'sima' ),
                    'options'   => array(
                                        ''      => esc_html__( 'No sidebar', 'sima' ),
                                        'left'  => esc_html__( 'Left sidebar', 'sima' ),
                                        'right' => esc_html__( 'Right sidebar', 'sima' ),
                                        )
                ),
            )
        );

        $this->sections[] = array(
            'icon'      => 'el-icon-folder',
            'title'     => esc_html__( 'Portfolio', 'sima' ),
            'fields'    => array(
                array(
                    'id'        => 'fwp_portfolio_slug',
                    'type'      => 'text',
                    'title'     => esc_html__( 'Custom Slug', 'sima' ),
                    'desc'      => esc_html__( 'Use this option in order to change the default portfolio slug (default fwp_project), you need to refresh your permalink page after updating this field.', 'sima' ),
                    'default'   => 'fwp_project'
                ),
            )
        );

        $this->sections[] = array(
            'icon'      => 'el-icon-inbox',
            'title'     => esc_html__('Footer', 'sima'),
            'fields'    => array(
                array(
                    'id'        => 'footer_copy',
                    'type'      => 'textarea',
                    'title'     => esc_html__('Footer copyright (left)', 'sima'),
                    'subtitle'  => esc_html__('Place here your copyright info.', 'sima'),
                    'default'   => ''
                ),
                array(
                    'id'        => 'social_profiles',
                    'type'      => 'multi_text',
                    'title'     => esc_html__( 'Social Networks Profiles', 'sima' ),
                    'desc'  => esc_html__( 'Icon | Profile URL (example: fa fa-facebook | https://facebook.com/fastwpthemes)', 'sima' )
                ),
            )
        );

        $this->sections[] = array(
            'icon'      => 'el-icon-inbox',
            'title'     => esc_html__('404 Page', 'sima'),
            'fields'    => array(
                array(
                    'id'        => 'fwp_404_image',
                    'type'      => 'media',
                    'url'       => true,
                    'title'     => esc_html__( 'Background Image', 'sima' ),
                    'subtitle'  => esc_html__( 'Background image on 404 page', 'sima' )
                ),
            ),
        );

    }

    public static function getMetaboxes( $metaboxes ) {
        $template_page = array( array(
            'icon'          => 'el-icon-lines',
            'icon_class'    => 'icon_large',
            'title'         => esc_html__( 'Menu', 'sima' ),
            'fields'        => array(
                array(
                    'id'        => 'menu_color',
                    'type'      => 'select',
                    'title'     => esc_html__( 'Menu Color', 'sima' ),
                    'options'   => array(
                                        'black' => esc_html__( 'Black', 'sima' ),
                                        'light' => esc_html__( 'Light', 'sima' )
                                        )
                ),
            )
        ) );

        $portfolio_meta = array( array(
            'icon'          => 'el-icon-screen',
            'icon_class'    => 'icon_large',
            'title'         => esc_html__( 'General', 'sima' ),
            'fields'        => array(
                array(
                    'id'        => 'portfolio_image_width',
                    'type'      => 'select',
                    'title'     => esc_html__( 'Image Width', 'sima' ),
                    'options'   => array(
                                        ''      => esc_html__( 'Default', 'sima' ),
                                        'w2'    => esc_html__( 'Wide', 'sima' )
                                        )
                ),
                array(
                    'id'        => 'portfolio_image_height',
                    'type'      => 'select',
                    'title'     => esc_html__( 'Image Height', 'sima' ),
                    'options'   => array(
                                        ''      => esc_html__( 'Default', 'sima' ),
                                        'h2'    => esc_html__( 'Tall', 'sima' )
                                        )
                ),
                array(
                    'id'        => 'portfolio_template',
                    'type'      => 'select',
                    'title'     => esc_html__( 'Template', 'sima' ),
                    'options'   => array(
                                        'default'   => esc_html__( 'Defapt', 'sima' ),
                                        2           => esc_html__( 'Content Right', 'sima' ),
                                        3           => esc_html__( 'Content Left', 'sima' ),
                                        )
                ),
        		array(
        			'id'        => 'hero_post_text_color',
        			'type'      => 'select',
        			'title'     => esc_html__( 'Hero Text Color', 'sima' ),
                    'options'   => array(
                                        'black' => esc_html__( 'Black', 'sima' ),
                                        'white' => esc_html__( 'White', 'sima' )
                                        )
        		),
            )
        ) );

        $portfolio_meta[] = array(
            'icon'          => 'el-icon-gallery',
            'icon_class'    => 'icon_large',
            'title'         => esc_html__( 'Gallery & Info', 'sima' ),
            'fields'        => array(
        		array(
        			'id'        => 'project_client',
        			'type'      => 'text',
        			'title'     => esc_html__( 'Client Info', 'sima' )
        		),
        		array(
        			'id'        => 'project_date',
        			'type'      => 'text',
        			'title'     => esc_html__( 'Date Info', 'sima' )
        		),
        		array(
        			'id'        => 'project_author',
        			'type'      => 'text',
        			'title'     => esc_html__( 'Images By', 'sima' )
        		),
        		array(
        			'id'        => 'project_gallery',
        			'type'      => 'slides',
        			'title'     => esc_html__( 'Gallery', 'sima' ),
        			'subtitle'  => esc_html__( 'Upload images or add from media library.', 'sima' ),
        			'placeholder'=> array(
        			                    'title' => esc_html__( 'Title', 'sima' ),
        		                    ),
        			'show' => array(
        				'title' => true,
                        'description' => false,
        				'url' => false,
        			)
                ),
                array(
                    'id'        => 'project_gallery_type',
                    'type'      => 'select',
                    'title'     => esc_html__( 'Gallery Type', 'sima' ),
                    'options'   => array(
                                        'images'    => esc_html__( 'Images List', 'sima' ),
                                        'gallery'   => esc_html__( 'Gallery', 'sima' )
                                        )
                ),
            )
        );

        $portfolio_meta[] = array(
            'icon'          => 'el-icon-lines',
            'icon_class'    => 'icon_large',
            'title'         => esc_html__( 'Navigation', 'sima' ),
            'fields'        => array(
        		array(
        			'id'        => 'hide_nav',
        			'type'      => 'select',
        			'title'     => esc_html__( 'Hide Post Navigation', 'sima' ),
                    'options'   => array(
                                        ''  => esc_html__( 'No', 'sima' ),
                                        1   => esc_html__( 'Yes', 'sima' )
                                        )
        		),
            )
        );

    	$gallery_format_meta = array( array(
        	'icon' => 'el-icon-screen',
        	'fields' => array(
        		array(
        			'id'        => 'post-gallery',
        			'type'      => 'slides',
        			'title'     => esc_html__( 'Gallery Slider', 'sima' ),
        			'subtitle'  => esc_html__( 'Upload images or add from media library.', 'sima' ),
        			'placeholder'   => array(
        			'title'         => esc_html__( 'Title', 'sima' ),
        			),
        			'show' => array(
        				'title' => true,
                        'description' => false,
        				'url' => false,
        			)
        		),
        	)
        ) );

    	$portfolio_template = array();

        if( class_exists( '\fastwp_sima_shortcodes\Portfolio' ) ) {

            $portfolio_template[] = array(
            	'icon' => 'el-icon-screen',
            	'fields' => array(
            		array(
            			'id'        => 'portfolio_items',
            			'type'      => 'checkbox',
            			'title'     => esc_html__( 'Display these projects', 'sima' ),
            			'subtitle'  => esc_html__( 'If no projects checked, all will be included', 'sima' ),
            			'options'   => \fastwp_sima_shortcodes\Portfolio::all_posts()
            		),
            		array(
            			'id'        => 'portfolio_items_per_row',
            			'type'      => 'select',
            			'title'     => esc_html__( 'Items Per Row', 'sima' ),
    					'options'   => array(
        										2 => esc_html__( '2', 'sima' ),
        										3 => esc_html__( '3', 'sima' ),
        										4 => esc_html__( '4', 'sima' ),
        										5 => esc_html__( '5', 'sima' ),
        										6 => esc_html__( '6', 'sima' )
                                            ),
            		),
            		array(
            			'id'        => 'portfolio_boxed',
            			'type'      => 'select',
            			'title'     => esc_html__( 'Boxed', 'sima' ),
    					'options'   => array(
        										1   => esc_html__( 'Yes', 'sima' ),
        										0   => esc_html__( 'No', 'sima' )
                                            ),
            		),
            		array(
            			'id'        => 'portfolio_show_filters',
            			'type'      => 'select',
            			'title'     => esc_html__( 'Show Filters', 'sima' ),
    					'options'   => array(
        										1   => esc_html__( 'Yes', 'sima' ),
        										0   => esc_html__( 'No', 'sima' )
                                            ),
            		),
            		array(
            			'id'        => 'portfolio_remove_mt',
            			'type'      => 'select',
            			'title'     => esc_html__( 'Remove Margin Top', 'sima' ),
    					'options'   => array(
        										1   => esc_html__( 'Yes', 'sima' ),
        										0   => esc_html__( 'No', 'sima' )
                                            ),
            		),
            	)
            );

        }

        $template_hero = array( array(
            'icon'          => 'el-icon-video',
            'icon_class'    => 'icon_large',
            'title'         => esc_html__( 'Hero Page Options', 'sima' ),
            'fields'        => array(
        		array(
        			'id'        => 'hero_type',
        			'type'      => 'select',
        			'title'     => esc_html__( 'Hero Type', 'sima' ),
                    'options'   => array(
                                        'full'  => esc_html__( 'Full page', 'sima' ),
                                        'tst'   => esc_html__( 'Title & Subtitle', 'sima' )
                                        )
        		),
        		array(
        			'id'        => 'hero_title',
        			'type'      => 'text',
        			'title'     => esc_html__( 'Title', 'sima' )
        		),
        		array(
        			'id'        => 'hero_subtitle',
        			'type'      => 'text',
        			'title'     => esc_html__( 'Subtitle', 'sima' )
        		),
        		array(
        			'id'        => 'hero_text_color',
        			'type'      => 'select',
        			'title'     => esc_html__( 'Text Color', 'sima' ),
                    'options'   => array(
                                        'black' => esc_html__( 'Black', 'sima' ),
                                        'white' => esc_html__( 'White', 'sima' )
                                        )
        		),
            )
        ) );

        $template_post_hero = array( array(
            'icon'          => 'el-icon-video',
            'icon_class'    => 'icon_large',
            'title'         => esc_html__( 'Hero Page Options', 'sima' ),
            'fields'        => array(
        		array(
        			'id'        => 'hero_post_text_color',
        			'type'      => 'select',
        			'title'     => esc_html__( 'Text Color', 'sima' ),
                    'options'   => array(
                                        'black' => esc_html__( 'Black', 'sima' ),
                                        'white' => esc_html__( 'White', 'sima' )
                                        )
        		),
            )
        ) );

        // Declare metaboxes

        $metaboxes[] = array(
            'id'            => 'sidebar1',
            'title'         => esc_html__( 'Sima Options', 'sima' ),
            'post_types'    => array( 'post' ),
            'position'      => 'normal', // normal, advanced, side
            'priority'      => 'high', // high, core, default, low - Priorities of placement
            'sections'      => $template_post_hero,
        );

        $metaboxes[] = array(
            'id'            => 'sidebar2',
            'title'         => esc_html__( 'Sima Options', 'sima' ),
            'post_types'    => array( 'page', 'post' ),
            'position'      => 'normal', // normal, advanced, side
            'priority'      => 'high', // high, core, default, low - Priorities of placement
            'sections'      => $template_page,
        );

        $metaboxes[] = array(
            'id'            => 'sidebar3',
            'title'         => esc_html__( 'Sima Options', 'sima' ),
            'post_types'    => array( 'fwp_portfolio' ),
            'position'      => 'normal', // normal, advanced, side
            'priority'      => 'high', // high, core, default, low - Priorities of placement
            'sections'      => array_merge( $template_page, $portfolio_meta ),
        );

        $metaboxes[] = array(
		    'id'            => 'gallery-post-options',
            'title'         => esc_html__( 'Options', 'sima' ),
            'post_types'    => array( 'post' ),
            'position'      => 'normal', // normal, advanced, side
            'priority'      => 'high', // high, core, default, low - Priorities of placement
            'sections'      => $gallery_format_meta,
            'post_format'   => array( 'gallery' ),
        );

        $metaboxes[] = array(
		    'id'            => 'portfolio-post-options',
            'title'         => esc_html__( 'Options', 'sima' ),
            'post_types'    => array( 'page' ),
            'page_template' => array( 'template-portfolio.php' ),
            'position'      => 'normal', // normal, advanced, side
            'priority'      => 'high', // high, core, default, low - Priorities of placement
            'sections'      => $portfolio_template
        );

        $metaboxes[] = array(
		    'id'            => 'hero-template-post-options',
            'title'         => esc_html__( 'Options', 'sima' ),
            'post_types'    => array( 'page' ),
            'page_template' => array( 'template-hero.php', 'template-hero-container.php' ),
            'position'      => 'normal', // normal, advanced, side
            'priority'      => 'high', // high, core, default, low - Priorities of placement
            'sections'      => $template_hero
        );

        return $metaboxes;
    }

    public function setArguments() {

        $theme = wp_get_theme(); // For use with some settings. Not necessary.

        $this->args = array(
            // TYPICAL -> Change these values as you need/desire
            'opt_name'          => 'fastwp_sima_data',            // This is where your data is stored in the database and also becomes your global variable name.
            'display_name'      => $theme->get('Name'),     // Name that appears at the top of your panel
            'display_version'   => $theme->get('Version'),  // Version that appears at the top of your panel
            'menu_type'         => 'submenu',                  //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
            'allow_sub_menu'    => true,                    // Show the sections below the admin menu item or not
            'menu_title'        => esc_html__('Theme Options', 'sima'),
            'page_title'        => esc_html__('Theme Options', 'sima'),

            // You will need to generate a Google API key to use this feature.
            // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
            'google_api_key' => 'AIzaSyBPVwg6CaFLmKlxYjQu0bJGpxDN1p04S-Q', // Must be defined to add google fonts to the typography module

            'async_typography'  => false,                    // Use a asynchronous font on the front end or font string
            'admin_bar'         => true,                    // Show the panel pages on the admin bar
            'global_variable'   => '',                      // Set a different name for your global variable other than the opt_name
            'dev_mode'          => false,                    // Show the time the page took to load, etc
            'customizer'        => true,                    // Enable basic customizer support

            // OPTIONAL -> Give you extra features
            'page_priority'     => null,                    // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
            'page_parent'       => 'themes.php',            // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
            'page_permissions'  => 'manage_options',        // Permissions needed to access the options panel.
            'menu_icon'         => '',                      // Specify a custom URL to an icon
            'last_tab'          => '',                      // Force your panel to always open to a specific tab (by id)
            'page_icon'         => 'icon-themes',           // Icon displayed in the admin panel next to your menu_title
            'page_slug'         => '_options',              // Page slug used to denote the panel
            'save_defaults'     => true,                    // On load save the defaults to DB before user clicks save or not
            'default_show'      => false,                   // If true, shows the default value next to each field that is not the default value.
            'default_mark'      => '',                      // What to print by the field's title if the value shown is default. Suggested: *

            // CAREFUL -> These options are for advanced use only
            'transient_time'    => 60 * MINUTE_IN_SECONDS,
            'output'            => true,                    // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
            'output_tag'        => true,                    // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
            // 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.

            // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
            'database'              => '', // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
            'show_import_export'    => true, // REMOVE
            'system_info'           => false, // REMOVE

            // HINTS
            'hints' => array(
                'icon'          => 'icon-question-sign',
                'icon_position' => 'right',
                'icon_color'    => 'lightgray',
                'icon_size'     => 'normal',
                'tip_style'     => array( 'color' => 'light', 'shadow' => true, 'rounded' => false, 'style' => '' ),
                'tip_position'  => array( 'my' => 'top left',  'at' => 'bottom right' ),
                'tip_effect'    => array(
                    'show'      => array( 'effect' => 'slide', 'duration' => '500', 'event' => 'mouseover' ),
                    'hide'      => array( 'effect' => 'slide', 'duration'  => '500', 'event' => 'click mouseleave' ),
                ),
            )
        );

        // SOCIAL ICONS -> Setup custom links in the footer for quick links in your panel footer icons.
        $this->args['share_icons'][] = array(
            'url'   => 'http://twitter.com/fastwp',
            'title' => 'Follow FastWP on Twitter',
            'icon'  => 'el-icon-twitter'
        );
        $this->args['share_icons'][] = array(
            'url'   => 'http://themeforest.net/user/fastwp/portfolio',
            'title' => 'Fastwp Official Page',
            'icon'  => 'el-icon-link'
        );
        $this->args['share_icons'][] = array(
            'url'   => 'mailto:themes@fastwp.net',
            'title' => 'Send an email to fastwp',
            'icon'  => 'el-icon-envelope'
        );

    }

    public static function demo_load( $demo_active_import , $demo_directory_path ) {

        reset( $demo_active_import );
        $current_key = key( $demo_active_import );

        /* Menu import */
        $wbc_menu_array = array(
            'demo-sima' => 'Menu'
        );

        if ( isset( $demo_active_import[$current_key]['directory'] ) && !empty( $demo_active_import[$current_key]['directory'] ) && (array_key_exists($demo_active_import[$current_key]['directory'], $wbc_menu_array) || in_array( $demo_active_import[$current_key]['directory'], $wbc_menu_array )) ) {
            $top_menu = get_term_by( 'name', $wbc_menu_array[$demo_active_import[$current_key]['directory']], 'nav_menu' );

			if ( isset( $top_menu->term_id ) ) {
                set_theme_mod( 'nav_menu_locations', array(
                        'primary' => $top_menu->term_id
                    )
                );
            }
        }

        /* Homepage select */
        $wbc_home_pages = array(
            'demo-sima' => 'agenty'
        );
        if ( isset( $demo_active_import[$current_key]['directory'] ) && !empty( $demo_active_import[$current_key]['directory'] ) && array_key_exists( $demo_active_import[$current_key]['directory'], $wbc_home_pages ) ) {
            $page = get_page_by_title( $wbc_home_pages[$demo_active_import[$current_key]['directory']] );
            if ( isset( $page->ID ) ) {
                update_option( 'page_on_front', $page->ID );
                update_option( 'show_on_front', 'page' );
            }
        }

        /* Blog page select */
        $wbc_home_pages = array(
            'demo-gridpage' => 'blog',
        );
        if ( isset( $demo_active_import[$current_key]['directory'] ) && !empty( $demo_active_import[$current_key]['directory'] ) && array_key_exists( $demo_active_import[$current_key]['directory'], $wbc_home_pages ) ) {
            $page = get_page_by_title( $wbc_home_pages[$demo_active_import[$current_key]['directory']] );
            if ( isset( $page->ID ) ) {
                update_option( 'page_for_posts', $page->ID );
            }
        }

    }

    public static function change_demo_directory_path( $demo_directory_path ) {
        $demo_directory_path = get_template_directory() . '/demo-data/';
        return $demo_directory_path;
    }

    function filter_title( $title ) {
        return ucfirst( trim( str_replace( "-", " ", str_replace( 'demo', '', $title ) ) ) );
    }

}

// Init filters & actions

add_action( 'redux/metaboxes/fastwp_sima_data/boxes', array( 'fastwp_sima_core\redux', 'getMetaboxes' ) );
add_action( 'wbc_importer_after_content_import', array( 'fastwp_sima_core\redux', 'demo_load' ), 10, 2 );
add_action( 'wbc_importer_after_content_import', array( 'fastwp_sima_core\redux', 'change_demo_directory_path' ), 10, 2 );
add_action( 'wbc_importer_after_content_import', array( 'fastwp_sima_core\redux', 'filter_title' ), 10, 2 );