<?php

namespace fastwp_sima_shortcodes;

// Do not allow directly accessing this file.
if ( ! defined( 'ABSPATH' ) ) {
	die( 'Direct script access denied.' );
}

class CallToAction extends \fastwp_sima_core\main {

	function __construct() {
        self::add_new_shortcode( 'sima_call_to_action', array( __CLASS__, 'shortcode' ) );
        self::add_vc_block( $this->vc_block() );
	}

	public static function shortcode( $atts = array(), $content = '' ) {
        extract( shortcode_atts( array(
            'text'          => '',
            'link_name'     => '',
            'link_url'      => '',
            'style'         => 'gray',
            'custom_color'  => '#f1f1f1',
            'custom_text'   => '',
            'type'          => '',
            'extra_class'   => ''
        ), $atts ) );

        $class = $text_class = $button_class = array();

        if( !empty( $extra_class ) ) {
            $class[] = $extra_class;
        }
        if( $style == 'black' ) {
            $bg_color       = '#222222';
            $text_class[]   = 'light-content';
            $button_class[] = 'light';
        } else if( $style == 'custom' ) {
            $bg_color       = $custom_color;
            if( $custom_text == 'light' ) {
                $text_class[]   = 'light-content';
                $button_class[] = 'light';
            }
        } else {
            $bg_color = '#f1f1f1';
        }

        $markup = '';

        if( $type == 'inline' ) {
            $markup .= '<div' . ( !empty( $class ) ? ' class="' . esc_attr( implode( ' ', $class ) ) . '"' : '' ) . ' data-bg-color="' . esc_attr( $bg_color ) . '">
            				<div class="gap-100"></div>
                                <div class="call__to__action">
                					<div class="action action__75">
                						<h3>' . wp_kses( $text, array( 'br' => array() ) ) . '</h3>
                					</div>

                					<div class="action action__25">
                						<a href="#" class="btn btn-block' . ( !empty( $button_class ) ? ' ' . esc_attr( implode( ' ', $button_class ) ) : '' ) . '">' . esc_html( $link_name ) . '</a>
                					</div>
                                </div>
            				<div class="gap-100"></div>
            			</div>';
        } else {
            $markup .= '<div' . ( !empty( $class ) ? ' class="' . esc_attr( implode( ' ', $class ) ) . '"' : '' ) . ' data-bg-color="' . esc_attr( $bg_color ) . '">
            				<div class="gap-100"></div>
            				<div class="call__to__action">
            					<div class="action action__100' . ( !empty( $text_class ) ? ' ' . esc_attr( implode( ' ', $text_class ) ) : '' ) . ' text-center">
            						<h3>' . wp_kses( $text, array( 'br' => array() ) ) . '</h3>
            						<p><a href="' . esc_url( $link_url ) . '" class="btn' . ( !empty( $button_class ) ? ' ' . esc_attr( implode( ' ', $button_class ) ) : '' ) . '">' . esc_html( $link_name ) . '</a></p>
            					</div>
            				</div>
            				<div class="gap-100"></div>
            			</div>';
        }

        return $markup;
    }

    private function vc_block() {
        return array(
			"name"      => esc_html__( 'Call To Action', 'sima' ),
			"base"      => 'sima_call_to_action',
			"icon"      => get_template_directory_uri() . "/assets/img/sima_vc_icon.png",
			"category"  => esc_html__( 'Sima Elements', 'sima' ),
			"params"    => array(
                array(
					"save_always"   => true,
					"type"          => 'textfield',
					"holder"        => false,
					"heading"       => esc_html__( 'Text/Title', 'sima' ),
					"param_name"    => 'text',
					"admin_label"   => true
                ),
                array(
					"save_always"   => true,
					"type"          => 'textfield',
					"holder"        => false,
					"heading"       => esc_html__( 'Link Name', 'sima' ),
					"param_name"    => 'link_name',
					"admin_label"   => true
                ),
                array(
					"save_always"   => true,
					"type"          => 'textfield',
					"holder"        => false,
					"heading"       => esc_html__( 'Link URL', 'sima' ),
					"param_name"    => 'link_url',
					"admin_label"   => true
                ),
				array(
					"save_always"   => true,
					"type"          => 'dropdown',
					"heading"       => esc_html__( 'Background', 'sima' ),
					"param_name"    => 'style',
					'value'         => array(
    										esc_html__( 'Gray', 'sima' )    => 'gray',
    										esc_html__( 'Black', 'sima' )   => 'black',
    										esc_html__( 'Custom', 'sima' )  => 'custom'
                                            ),
					"admin_label"   => true
				),
				array(
					"save_always"   => true,
					"type"          => 'colorpicker',
					"heading"       => esc_html__( 'Background Color', 'sima' ),
					"param_name"    => 'custom_color',
					"admin_label"   => true,
                    'dependency'    => array( 'element' => 'style', 'value' => array( 'custom' ) )
				),
				array(
					"save_always"   => true,
					"type"          => 'dropdown',
					"heading"       => esc_html__( 'Text Color', 'sima' ),
					"param_name"    => 'custom_text',
					'value'         => array(
    										esc_html__( 'Black', 'sima' )   => 'black',
    										esc_html__( 'White', 'sima' )   => 'light'
                                            ),
					"admin_label"   => true,
                    'dependency'    => array( 'element' => 'style', 'value' => array( 'custom' ) )   
				),
				array(
					"save_always"   => true,
					"type"          => 'dropdown',
					"heading"       => esc_html__( 'Type', 'sima' ),
					"param_name"    => 'type',
					'value'         => array(
    										esc_html__( 'Default', 'sima' )     => '',
    										esc_html__( 'Inline', 'sima' )      => 'inline',
                                            ),
					"admin_label"   => true
				),
				array(
					"save_always"   => true,
					"group"         => esc_html__( 'Extra', 'sima' ),
					"type"          => 'textfield',
					"heading"       => esc_html__( 'Extra Class', 'sima' ),
					"param_name"    => 'extra_class',
					"admin_label"   => false,
					"description"   => esc_html__( 'Use this options to add an extra class to element, you can use this for custom css', 'sima' )
				),
			 ),
		);
    }

}

?>