<?php

namespace fastwp_sima_shortcodes;

// Do not allow directly accessing this file.
if ( ! defined( 'ABSPATH' ) ) {
	die( 'Direct script access denied.' );
}

class Map extends \fastwp_sima_core\main {

	function __construct() {
        self::add_new_shortcode( 'sima_map', array( __CLASS__, 'shortcode' ) );
        self::add_vc_block( $this->vc_block() );
	}

	public static function shortcode( $atts, $content ) {
        global $fastwp_sima_custom_js;
		extract( shortcode_atts(array(
			'center'		=> '44.434596,26.080533',
            'pins'          => '',
			'map_style'		=> 'fastwp',
			'map_zoom'		=> 8,
			'map_izoom'		=> 12,
            'extra_class'   => ''
		), $atts ) );

        $pins = vc_param_group_parse_atts( $pins );

        if( empty( $pins ) ) {
            return ;
        }

        $mapId = 'map' . rand( 1, 99999 );

        $pin_list = array();

        foreach( $pins as $pin ) {
            $marker_pos = explode( ',', $pin['marker_addr'] );
    		$fastwp_sima_custom_js[$mapId]['gmap_marker_title'][]  = $pin_title = esc_html( $pin['marker_title'] );
    		$fastwp_sima_custom_js[$mapId]['gmap_marker_addrs'][]  = $marker_lat_lng = array_map( 'trim', $marker_pos );
    		$fastwp_sima_custom_js[$mapId]['gmap_marker_ct'][]     = $pin['marker_content'];
            $fastwp_sima_custom_js[$mapId]['gmap_marker'][] = get_template_directory_uri() . '/assets/img/map-marker.png';
            $pin_list[] = array( 'title' => $pin_title,
                                 'lat' => $marker_lat_lng[0],
                                 'lng' => $marker_lat_lng[1]
                                );
        }

		$map_center_pos = explode( ',', $center );
		$fastwp_sima_custom_js[$mapId]['gmap_center']     = $center_lat_lng = array_map( 'trim', $map_center_pos );
		$fastwp_sima_custom_js[$mapId]['gmap_style'] 		= $map_style;
		$fastwp_sima_custom_js[$mapId]['gmap_zoom'] 		= $map_zoom;
		$fastwp_sima_custom_js[$mapId]['gmap_izoom'] 		= $map_izoom;

        return '<div class="map-container' . ( !empty( $extra_class ) ? ' ' . esc_attr( $extra_class ) : '' ) . '">
        <div class="fwp-map" data-mapId="' . esc_attr( $mapId ) . '"></div>
        </div>';
	}

    private function vc_block() {
        return array(
			"name"      => esc_html__( 'Map', 'sima' ),
			"base"      => 'sima_map',
			"icon"      => get_template_directory_uri() . "/assets/img/sima_vc_icon.png",
			"category"  => esc_html__( 'Sima Elements', 'sima' ),
			"params"    => array(
				array(
					"save_always"   => true,
					"type"          => "textfield",
					"holder"        => false,
					"heading"       => esc_html__( 'Center of map', 'sima' ),
					"param_name"    => 'center',
					"value"         => '44.434596,26.080533',
					"admin_label"   => true
				),
				array(
					"save_always"   => true,
					"type" 			=> "dropdown",
					"holder"        => false,
					"heading" 		=> esc_html__( 'Map style', 'sima' ),
					"param_name" 	=> "map_style",
					"value" 		=> array( 'FastwpStyle' => 'fastwp', 'Default Google Style' => 'default' ),
					"description" 	=> esc_html__( 'Choose map style', 'sima' ),
					"admin_label"   => true,
				),
				array(
					"save_always"   => true,
					"type"          => "textfield",
					"holder"        => false,
					"heading"       => esc_html__( 'Default zoom', 'sima' ),
					"param_name"    => "map_zoom",
					"value"         => '8',
					"admin_label"   => true,
				),
				array(
					"save_always"   => true,
					"type"          => "textfield",
					"holder"        => false,
					"heading"       => esc_html__( 'Zoom of map when click on a marker', 'sima' ),
					"param_name"    => "map_izoom",
					"value"         => '12',
					"admin_label"   => true
				),
				array(
                    'type'          => 'param_group',
                    'param_name'    => 'pins',
                    'params'        =>  array(
                            				array(
                            					"save_always"   => true,
                            					"type"          => 'textfield',
                            					"holder"        => false,
                            					"heading"       => esc_html__( 'Marker coordinates', 'sima' ),
                            					"param_name"    => 'marker_addr',
                            					"value"         => '44.434596,26.080533',
                            					"admin_label"   => false,
                            				),
                            				array(
                            					"save_always"   => true,
                            					"type"          => 'textfield',
                            					"holder"        => false,
                            					"heading"       => esc_html__( 'Marker title', 'sima' ),
                            					"param_name"    => 'marker_title',
                            					"value"         => 'Our Location',
                            					"admin_label"   => false,
                            				),
                            				array(
                            					"save_always"   => true,
                            					"type"          => 'textarea',
                            					"holder"        => false,
                            					"heading"       => esc_html__( 'Marker content', 'sima' ),
                            					"param_name"    => 'marker_content',
                            					"admin_label"   => false,
                            				)
                                        )
                ),
 				array(
                    "group"         => esc_html__( 'Extras', 'sima' ),
					"save_always"   => true,
					"type"          => "textfield",
					"holder"        => false,
					"heading"       => esc_html__("Extra class", 'sima' ),
					"param_name"    => "extra_class",
					"admin_label"   => true
				),
			)
		);
    }

}

?>