<?php

namespace fastwp_sima_shortcodes;

// Do not allow directly accessing this file.
if ( ! defined( 'ABSPATH' ) ) {
	die( 'Direct script access denied.' );
}

class Portfolio extends \fastwp_sima_core\main {

	function __construct() {
        self::add_new_shortcode( 'sima_portfolio', array( __CLASS__, 'shortcode' ) );
        self::add_vc_block( $this->vc_block() );
	}

    protected static function get_terms() {
        $get_terms = get_terms( array(
            'taxonomy'  => 'portfolio-category',
            'hide_empty'=> false,
        ) );

        $terms = array();

        foreach( $get_terms as $term ) {
            $terms[$term->term_id] = array( 'name' => $term->name, 'slug' => $term->slug );
        }

        return $terms;
    }

    protected static function get_terms_with_name() {
        $get_terms = get_terms( array(
            'taxonomy'  => 'portfolio-category',
            'hide_empty'=> false,
        ) );

        $terms = array();

        foreach( $get_terms as $term ) {
            $terms[$term->name] = $term->term_id;
        }

        return $terms;
    }

    protected static function all_post_categories( $array = false, $before = '', $after = '', $separator = ' / ' ) {
        $terms = get_the_terms( get_the_ID(), 'portfolio-category' );

        if( !isset( $terms->errors ) && !empty( $terms ) ) {
            $items = array();

            foreach( $terms as $term ) {
                $items[$term->term_id] = array( 'name' => $term->name, 'slug' => $term->slug );
            }

            if( $array ) {
                return $items;
            }

            $markup = $before;
            $markup .= implode( $separator, array_keys( $items ) );
            $markup .= $after;

            return $markup;
        }

        return ( $array ? array() : '' );
    }

    public static function all_posts() {
        $query_options = array(
                                'post_type'         => 'fwp_portfolio',
                                'posts_per_page'    => -1
                            );

        $loop = new \WP_Query( $query_options );

        $posts = array();

        if( $loop->have_posts() ) {
            while ( $loop->have_posts() ) {
                $loop->the_post();
                $posts[get_the_ID()] = get_the_title();
            }
        }

        return $posts;
    }

    protected function all_posts_with_img() {
        $query_options = array(
                                'post_type'         => 'fwp_portfolio',
                                'posts_per_page'    => -1
                            );

        $loop = new \WP_Query( $query_options );

        $posts = array();

        if( $loop->have_posts() ) {
            while ( $loop->have_posts() ) {
                $loop->the_post();
                $posts['<img src="' . esc_url( get_the_post_thumbnail_url() ) . '" title="' . esc_attr( get_the_title() ) . '" />'] = get_the_ID();
            }
        }

        return $posts;
    }

	public static function shortcode( $atts = array(), $content = '' ) {
        extract( shortcode_atts( array(
            'view_project'  => '',
            'iposts'        => array(),
            'iposts_by_id'  => '',
            'icategories'   => array(),
            'eposts'        => array(),
            'ecategories'   => array(),
            'show_filters'  => true,
            'show_container'=> false,
            'items'         => 4,
            'extra_class'   => ''
        ), $atts ) );

        $class = array();

        if( !empty( $extra_class ) ) {
            $class[] = $extra_class;
        }

        $query_options = array(
                                'post_type'         => 'fwp_portfolio',
                                'posts_per_page'    => -1,
                    			'suppress_filters' => true
                            );

        if( !empty( $iposts ) ) {
            $query_options['post__in']  = ( gettype( $iposts ) == 'array' ? $iposts : explode( ',', $iposts ) );
        }

        if( !empty( $iposts_by_id ) ) {
            $query_options['post__in']  = array_filter( explode( ',', $iposts_by_id ) );
            $query_options['orderby']   = 'post__in';
        }

        if( !empty( $eposts ) ) {
            $query_options['post__not_in'] = ( gettype( $eposts ) == 'array' ? $eposts : explode( ',', $eposts ) );
        }

        if( !empty( $icategories ) ) {
            $query_options['tax_query']                 = array();
            $query_options['tax_query'][0]['taxonomy']  = 'portfolio-category';
            $query_options['tax_query'][0]['field']     = 'term_id';
            $query_options['tax_query'][0]['terms']     = ( gettype( $icategories ) == 'array' ? $icategories : explode( ',', $icategories ) );
            $query_options['tax_query'][0]['operator']  = 'IN';
        } else if( !empty( $ecategories ) ) {
            $query_options['tax_query']                 = array();
            $query_options['tax_query'][0]['taxonomy']  = 'portfolio-category';
            $query_options['tax_query'][0]['field']     = 'term_id';
            $query_options['tax_query'][0]['terms']     = ( gettype( $ecategories ) == 'array' ? $ecategories : explode( ',', $ecategories ) );
            $query_options['tax_query'][0]['operator']  = 'NOT IN';
        }

        $loop = new \WP_Query( $query_options );

        $markup = '<div' . ( !empty( $class ) ? ' class="' . esc_attr( implode( ' ', $class ) ) . '"' : '' ) . '>';

        if( (boolean) $show_container ) {
            $markup .= '<div class="container">';
        }

        if( (boolean) $show_filters ) {
            $the_terms = self::get_terms();

            if( !empty( $the_terms ) ) {
                $markup .= '<ul class="filters">';
                $markup .= '<li data-filter="*" class="active">' . ( !empty( $view_project ) ? esc_html( $view_project ) : esc_html__( 'show all', 'sima' ) ) . '</li>';
                foreach( $the_terms as $term_id => $term ) {
                    $markup .= '<li data-filter=".' . esc_attr( $term['slug'] ) . '">' . esc_html( $term['name'] ) . '</li>';
                }
                $markup .= '</ul>';
            }
        }

        if( $loop->have_posts() ) {
            $markup .= '<div class="gallery" data-cols="' . esc_attr( $items ) . '" data-ratio="1:1" data-margin="0">';
            while ( $loop->have_posts() ) {
                $loop->the_post();

                $categories = self::all_post_categories( true );

                $slug   = $cats = array();

                $width  = get_post_meta( get_the_ID(), 'portfolio_image_width', true );
                $height = get_post_meta( get_the_ID(), 'portfolio_image_height', true );

                if( in_array( $width, array( 'w2' ) ) ) {
                    $slug[] = $width;
                }

                if( in_array( $height, array( 'h2' ) ) ) {
                    $slug[] = $height;
                }

                foreach( $categories as $cat_id => $cat ) {
                    $slug[] = $cat['slug'];
                    $cats[] = $cat['name'];
                }

                $markup .= '<div class="entry work-entry' . ( !empty( $slug ) ? ' ' . implode( ' ', $slug ) : '' ) . '">
            					<a href="' . esc_url( get_the_permalink() ) . '">
            						<div class="entry__content" data-bg="' . esc_url( get_the_post_thumbnail_url() ) . '">
            							<div class="entry__overlay">
            								<div class="overlay__content" data-pos="top">
            									<div class="title">' . get_the_title() . '</div>
                                                ' . ( !empty( $cats ) ? '<div class="cat">' . implode( ' ', $cats ) . '</div>' : '' ) . '
            								</div>
            							</div>
            						</div>
            					</a>
            				</div>';

            }
            $markup .= '</div>';
        }

        if( (boolean) $show_container ) {
            $markup .= '</div>';
        }

        $markup .= '</div>';

        return $markup;
    }

    private function vc_block() {
        return array(
			"name"      => esc_html__( 'Portfolio', 'sima' ),
			"base"      => 'sima_portfolio',
			"icon"      => get_template_directory_uri() . "/assets/img/sima_vc_icon.png",
			"category"  => esc_html__( 'Sima Elements', 'sima' ),
			"params"    => array(
				array(
					"save_always"   => true,
					"type"          => 'dropdown',
					"heading"       => esc_html__( 'Show Filters', 'sima' ),
					"param_name"    => 'show_filters',
					'value'         => array(
    										esc_html__( 'Yes', 'sima' ) => 1,
    										esc_html__( 'No', 'sima' )  => 0
                                            ),
					"admin_label"   => true
				),
                array(
					"save_always"   => true,
					"type"          => 'textfield',
					"holder"        => false,
					"heading"       => esc_html__( '"View Project" Label', 'sima' ),
					"param_name"    => 'view_project',
					"admin_label"   => true,
                    'dependency'    => array( 'element' => 'show_filters', 'value' => array( '1' ) )
                ),
				array(
					"save_always"   => true,
					"type"          => 'dropdown',
					"heading"       => esc_html__( 'Show Container', 'sima' ),
					"param_name"    => 'show_container',
					'value'         => array(
    										esc_html__( 'Yes', 'sima' ) => 1,
    										esc_html__( 'No', 'sima' )  => 0
                                            ),
					"admin_label"   => true
				),
				array(
					"save_always"   => true,
					"type"          => 'dropdown',
					"heading"       => esc_html__( 'Items Per Row', 'sima' ),
					"param_name"    => 'items',
					'value'         => array(
    										esc_html__( '2', 'sima' )   => 2,
    										esc_html__( '3', 'sima' )   => 3,
    										esc_html__( '4', 'sima' )   => 4,
    										esc_html__( '5', 'sima' )   => 5,
    										esc_html__( '6', 'sima' )   => 6
                                        ),
					"admin_label"   => true
				),
                array(
					"save_always"   => true,
					"group"         => esc_html__( 'Include', 'sima' ),
					"type"          => 'checkbox',
					"holder"        => false,
					"heading"       => esc_html__( 'Include These Projects', 'sima' ),
                    'value'         => $this->all_posts_with_img(),
					"param_name"    => 'iposts',
                    'edit_field_class'=> 'vc_custom_ptf_img',
					"admin_label"   => false
                ),
                array(
					"save_always"   => true,
					"group"         => esc_html__( 'Include', 'sima' ),
					"type"          => 'textfield',
					"holder"        => false,
					"heading"       => esc_html__( 'OR Include These Projects By Id (separated with comma)', 'sima' ),
					"param_name"    => 'iposts_by_id',
					"admin_label"   => false
                ),
                array(
					"save_always"   => true,
					"group"         => esc_html__( 'Include', 'sima' ),
					"type"          => 'checkbox',
					"holder"        => false,
					"heading"       => esc_html__( 'Include These Categories', 'sima' ),
                    'value'         => $this->get_terms_with_name(),
					"param_name"    => 'icategories',
					"admin_label"   => false
                ),
                array(
					"save_always"   => true,
					"group"         => esc_html__( 'Exclude', 'sima' ),
					"type"          => 'checkbox',
					"holder"        => false,
					"heading"       => esc_html__( 'Exclude These Projects', 'sima' ),
                    'value'         => $this->all_posts_with_img(),
					"param_name"    => 'eposts',
                    'edit_field_class'=> 'vc_custom_ptf_img',
					"admin_label"   => false
                ),
                array(
					"save_always"   => true,
					"group"         => esc_html__( 'Exclude', 'sima' ),
					"type"          => 'checkbox',
					"holder"        => false,
					"heading"       => esc_html__( 'Exclude These Categories', 'sima' ),
                    'value'         => $this->get_terms_with_name(),
					"param_name"    => 'ecategories',
					"admin_label"   => false
                ),
				array(
					"save_always"   => true,
					"group"         => esc_html__( 'Extra', 'sima' ),
					"type"          => 'textfield',
					"heading"       => esc_html__( 'Extra Class', 'sima' ),
					"param_name"    => 'extra_class',
					"admin_label"   => false,
					"description"   => esc_html__( 'Use this options to add an extra class to element, you can use this for custom css', 'sima' )
				),
			 ),
		);
    }

}

?>