<?php

// FastWP Framework - filters

namespace fastwp_sima_theme;

// Do not allow directly accessing this file.
if ( ! defined( 'ABSPATH' ) ) {
    die( 'Direct script access denied.' );
}

class filters extends \fastwp_sima_core\main {

    /* Custom search form */

    public static function search_form() {
        return '<div class="widget widget__search">
        			<div class="widget__content">
        				<form method="get" action="' . esc_url( home_url( '/' ) ) . '">
        					<div class="form-group">
        						<input name="s" placeholder="' . esc_attr__( 'Type &amp; Hit Enter', 'sima' ) . '" type="search">
        					</div>
        				</form>
        			</div>
        		</div>';
    }

    /* Footer content */

    public static function footer_content() {
		global $fastwp_sima_custom_js;
        if( !empty( $fastwp_sima_custom_js ) ) {
		    wp_localize_script( 'custom', 'fastwp', $fastwp_sima_custom_js );
        }
        if( \fastwp_sima_theme\utils::get_option( 'fwp_custom_js' ) != '' ) {
            echo '<script>';
            echo \fastwp_sima_theme\utils::get_option( 'fwp_custom_js' );
            echo '</script>';
        }
    }

    /* Comment form */

    public static function comment_form_args() {
        global $user_identity;

        $commenter  = wp_get_current_commenter();
        $req        = get_option( 'require_name_email' );
        $aria_req   = ( $req ? " aria-required='true'" : '' );

        $args = array(
            'id_form'           => 'commentform',
            'class_form'        => '',
            'id_submit'         => 'submit',
            'class_submit'      => 'button mb-0',
            'name_submit'       => 'submit',
            'title_reply'       => esc_html__( 'Leave a Reply', 'sima' ),
            'title_reply_to'    => esc_html__( 'Leave a Reply to %s', 'sima' ),
            'cancel_reply_link' => esc_html__( 'Cancel Reply', 'sima' ),
            'label_submit'      => esc_html__( 'Post Comment', 'sima' ),
            'format'            => 'xhtml',

            'comment_field'     => '<div class="form-group">
                                        <textarea name="comment" id="comment" placeholder="' . esc_attr__( 'Your Comment', 'sima' ) . '"></textarea>
                                    </div>',

            'must_log_in'       => '<div class="form-group">
                                        <p class="must-log-in">' . sprintf( esc_html__( 'You must be %s to post a comment.', 'sima' ), '<a href="' . esc_url( wp_login_url( apply_filters( 'the_permalink', get_permalink() ) ) ) . '">' . esc_html__( 'logged in', 'sima' ) . '</a>' ) . '</p>
                                    </div>',

            'logged_in_as'      => '<div class="form-group">
                                        <p class="logged-in-as">' .
                                            esc_html__( 'Logged in as', 'sima' ) . ' <a href="' . esc_url( admin_url( 'profile.php' ) ) . '">' . $user_identity . '</a>  <a href="' . esc_url( wp_logout_url( apply_filters( 'the_permalink', get_permalink( ) ) ) )  . '" title="' . esc_attr__( 'Log out of this account', 'sima' ) . '">' . esc_html__( 'Log out?', 'sima' ) . '</a>
                                        </p>
                                    </div>',

            'comment_notes_before'
                                => '<div class="form-group">
                                        <p class="small mb-5">' . esc_html__( 'Your email address will not be published. Required fields are marked *', 'sima' ) . '</p>
                                    </div>',

             'submit_button'    => '<div class="form-group">
                                        <input name="%1$s" type="submit" id="%2$s" class="%3$s" value="%4$s" />
                                    </div>',

            'fields'        => array(
                                    'author' =>
                                    '<div class="form-group">
                                        <input name="author" id="author" placeholder="' . esc_attr__( 'Your Name', 'sima' ) . ( $req ? '*' : '' ) . '" type="text"' . $aria_req . ' />
                                    </div>',

                                    'email' =>
                                    '<div class="form-group">
                                        <input name="email" id="email" placeholder="' . esc_attr__( 'Email', 'sima' ) . ( $req ? '*' : '' ) . '" type="email"' . $aria_req . ' />
                                    </div>',

                                    'url' =>
                                    '<div class="form-group">
                                        <input name="url" id="url" placeholder="' . esc_attr__( 'URL', 'sima' ) . '" type="text" />
                                    </div>'
                                    )
        );

        return $args;
    }

    /* Reply link filter */

    public static function comment_reply_link( $link ) {
        return str_replace( 'comment-reply-link', 'reply comment-reply-link', $link );
    }

    /* Markup before comment form */

    public static function before_comment_form() {
        echo '<div class="post__comments__form">';
    }

    /* Markup after comment form */

    public static function after_comment_form() {
        echo '</div>';
    }

    /* Comment */

    public static function comment( $comment, $args, $depth ) {
        switch ( $comment->comment_type ) {

        case 'pingback':
        case 'trackback': ?>

        <li class="com-pingback"><p><?php esc_html_e( 'Pingback:', 'sima' ); ?> <b><?php comment_author_link(); ?></b> <?php edit_comment_link( esc_html__( 'Edit', 'sima' ), ' / <i class="edit-link">', '</i>' ); ?></p>
        <?php echo get_comment_date(); ?>

        <?php break;
        default: ?>

        <li class="comment">
        	<div class="comment__img">
        		<img src="<?php echo get_avatar_url( get_comment_author_email() ); ?>" alt="<?php echo get_comment_author(); ?>" />
        	</div>
        	<div class="comment__content">
        		<div class="name"><?php echo get_comment_author(); ?></div>
        		<div class="date"><?php echo get_comment_date(); ?></div>
        		<p><?php comment_text(); ?> <?php edit_comment_link( esc_html__( 'Edit', 'sima' ), '', '' ); ?></p>

        		<?php comment_reply_link( array_merge( $args, array( 'reply_text' => esc_html__( 'Reply', 'sima' ), 'before'=> '', 'after' => '', 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
        	</div>

    <?php break;
        }
    }

    /* Comment close tag */

    public static function comment_close_tag( $post = 0 ) { ?>
        </li>
    <?php }

    /* VISUAL COMPOSER */

    public static function custom_css_classes_for_vc( $class_string, $tag ) {
        if( $tag == 'vc_row' || $tag == 'vc_row_inner' ) {
            $class_string = str_replace( array( 'vc_row', 'wpb_row', 'row-fluid', 'vc_row-fluid', 'vc_inner' ), array( 'row', '', '', '', '' ), $class_string );
        }

        if( $tag == 'vc_column' || $tag == 'vc_column_inner' ) {
            $class_string = str_replace( array( 'vc_column_container', 'wpb_column', 'vc_column-inner' ), array( 'column', '', '' ), $class_string );
            $class_string = preg_replace( '/vc_col-sm-(\d{1,2})/', 'col-$1', $class_string );
            $class_string = preg_replace( '/vc_col-md-(\d{1,2})/', 'col-md-$1', $class_string );
            $class_string = preg_replace( '/vc_col-lg-(\d{1,2})/', 'col-lg-$1', $class_string );
        }
        return $class_string;
    }

    public static function params_for_vc() {

        /* Row options */

        self::add_vc_param( 'vc_row', array(
            array(
                'type'          => 'dropdown',
                'group'         => esc_html__( 'Sima Row Options', 'sima' ),
                'heading'       => esc_html__( 'Use Container / Boxed', 'sima' ),
                'param_name'    => 'fwp_container',
                'value'         => array( esc_html__( 'No', 'sima' ) => '', esc_html__( 'Yes', 'sima' ) => 1 )
            ),
            array(
                'type'          => 'dropdown',
                'group'         => esc_html__( 'Sima Row Options', 'sima' ),
                'heading'       => esc_html__( 'Margins Top', 'sima' ),
                'param_name'    => 'fwp_margin_top',
                'value'         => array( esc_html__( 'No', 'sima' ) => '', esc_html__( 'Yes', 'sima' ) => 1 )
            ),
            array(
                'type'          => 'dropdown',
                'group'         => esc_html__( 'Sima Row Options', 'sima' ),
                'heading'       => esc_html__( 'Margins Bottom', 'sima' ),
                'param_name'    => 'fwp_margin_bottom',
                'value'         => array( esc_html__( 'No', 'sima' ) => '', esc_html__( 'Yes', 'sima' ) => 1 )
            ),
        ) );

    }

}

add_filter( 'get_search_form', array( 'fastwp_sima_theme\filters', 'search_form' ), 10 );
add_action( 'wp_footer', array( 'fastwp_sima_theme\filters', 'footer_content' ), 10 );
add_filter( 'comment_form_before', array( 'fastwp_sima_theme\filters', 'before_comment_form' ), 10 );
add_filter( 'comment_form_after', array( 'fastwp_sima_theme\filters', 'after_comment_form' ), 10 );
add_filter( 'comment_reply_link', array( 'fastwp_sima_theme\filters', 'comment_reply_link' ), 10 );