<?php

// FastWP Framework - markup

namespace fastwp_sima_theme;

// Do not allow directly accessing this file.
if ( ! defined( 'ABSPATH' ) ) {
	die( 'Direct script access denied.' );
}

class markup {

    /* Get the menu */

    public static function the_menu( $menu = 'primary' ) {
        $menu   = new \fastwp_sima_core\menu_create( $menu );
        $links  = $menu->get_grouped_links();
        $markup = '';

        if( !empty( $links ) ) {
            $markup .= '<ul class="main-nav menu">';

            foreach( $links as $link ) {
                $cols = get_post_meta( $link['ID'], '_menu_item_menutype', true );
                if( $cols === 'mega2' || $cols === 'mega3' || $cols === 'mega4' ) {
                    $link['classes'][] = 'has-mega-menu';
                }
                $markup .= '<li' . ( !empty( $link['classes'] ) ? ' class="' . esc_attr( implode( ' ', $link['classes'] ) ) . '"' : '' ) . '>
                <a href="' . esc_url( $link['url'] ) . '" class="ajax-link' . ( !empty( $link['is_active'] ) || !empty( $link['children_is_active'] ) ? ' active' : '' ) . '"' .
                ( !empty( $link['target'] ) ? ' target="' . esc_attr( $link['target'] ) . '"' : '' ) . ( !empty( $link['attr_title'] ) ? ' title="' . esc_attr( $link['attr_title'] ) . '"' : '' ) . '>' . esc_html( $link['title'] ) . '</a>';
                if( !empty( $link['subnav'] ) ) {
                    self::the_submenu_links( $markup, $link['subnav'], $link['ID'] );
                }
                $markup .= '</li>';
            }

            $markup .= '</ul>';
        }

        return $markup;
    }

    /* Get the submenu */

    private static function the_submenu_links( &$markup, $main_link, $parent_id ) {
        $cols = get_post_meta( $parent_id, '_menu_item_menutype', true );

        $nr_of_col = 1;
        $nr_of_items = count( $main_link );

        if( $cols === 'mega2' ) $nr_of_col = 2;
        if( $cols === 'mega3' ) $nr_of_col = 3;
        if( $cols === 'mega4' ) $nr_of_col = 4;

        $per_col = ceil( $nr_of_items / $nr_of_col );

        if( $nr_of_col !== 1 ) {
            $markup .= '<div class="mega-menu">';
        }

        $i = 1;
        $ti = 1;

        foreach( $main_link as $link ) {
            if( $nr_of_col !== 1 ) {
                if( $i == 1 )  {
                    $markup .= '<div class="col">
    		        <ul>';
                }
            } else if( $i == 1 ) {
                $markup .= '<ul>';
            }

            $markup .= '<li' . ( !empty( $link['classes'] ) ? ' class="' . esc_attr( implode( ' ', $link['classes'] ) ) . '"' : '' ) . '>
            <a href="' . esc_url( $link['url'] ) . '"' . ( !empty( $link['is_active'] ) || !empty( $link['children_is_active'] ) ? ' class="active"' : '' ) .
            ( !empty( $link['target'] ) ? ' target="' . esc_attr( $link['target'] ) . '"' : '' ) . ( !empty( $link['attr_title'] ) ? ' title="' . esc_attr( $link['attr_title'] ) . '"' : '' ) . '>' . esc_html( $link['title'] ) . '</a>';

            if( !empty( $link['subnav'] ) ) {
                self::the_submenu_links( $markup, $link['subnav'], $link['ID'] );
            }
            $markup .= '</li>';

            if( $nr_of_col !== 1 ) {
                if( $i == $per_col ) {
                    $markup .= '</ul>
    		        </div>';
                    $i = 0;
                } else if( $ti == $nr_of_items ) {
                    $markup .= '</ul>
    		        </div>';
                }

            } else if( $ti == $nr_of_items ) {
                $markup .= '</ul>';
            }
            $i++;
            $ti++;
        }

        if( $nr_of_col !== 1 ) {
            $markup .=' </div>';
        }

        return $markup;
    }

    /* Get the share links */

    public static function share_links() {
    	echo '<div class="gap-100"></div>
        <div class="share__project text-center">
        <h5>' . esc_html__( 'share project', 'sima' ) . '</h5>
    	<ul class="social">
    		<li><a href="' . esc_url( 'https://twitter.com/home?status=' . get_the_permalink() ) . '"><i class="fa fa-twitter"></i></a></li>
    		<li><a href="' . esc_url( 'https://www.facebook.com/sharer/sharer.php?u=' . get_the_permalink() ) . '"><i class="fa fa-facebook"></i></a></li>
    		<li><a href="' . esc_url( 'https://plus.google.com/share?url=' . get_the_permalink() ) . '"><i class="fa fa-google"></i></a></li>
    		<li><a href="' . esc_url( 'https://pinterest.com/pin/create/button/?url=' . get_the_permalink() ) . '"><i class="fa fa-pinterest"></i></a></li>
    	</ul>
        </div>';
    }

}