<?php

// Do not allow directly accessing this file.
if ( ! defined( 'ABSPATH' ) ) {
	die( 'Direct script access denied.' );
}

/*** Define Sima Theme constants ***/

if( !defined( 'FASTWP_SIMA_FRAMEWORK_DIR' ) ) {
    define( 'FASTWP_SIMA_FRAMEWORK_DIR', 'fastwp-framework' );
}

if( !defined( 'FASTWP_SIMA_DIR' ) ) {
    define( 'FASTWP_SIMA_DIR', get_template_directory() );
}

if( !defined( 'FASTWP_SIMA_URI' ) ) {
    define( 'FASTWP_SIMA_URI', get_template_directory_uri() );
}

/*** Autoload ***/

require_once FASTWP_SIMA_DIR . '/' . FASTWP_SIMA_FRAMEWORK_DIR . '/autoload.php';

/*** General ***/

if ( ! isset( $content_width ) ) $content_width = 900;
if ( is_singular() ) wp_enqueue_script( "comment-reply" );

/*** Redux framework ***/

new fastwp_sima_core\redux;

// Theme support

fastwp_sima_core\general::add_theme_support( 'menus,custom-logo,title-tag,post-thumbnails,automatic-feed-links' );
fastwp_sima_core\general::add_theme_support( 'post-formats',
    array(
        'gallery',
    )
);

add_action( 'init', array( 'fastwp_sima_core\general', 'register_theme_support' ), 1 );

// Add menu location

fastwp_sima_core\menu::add_menu( 'primary', esc_html__( 'Main menu', 'sima' ) );

// Language dir used for translation

fastwp_sima_core\general::text_domain_language_dir( 'sima' );

/*** List of the styles used in Sima Theme ***/

fastwp_sima_core\main::add_styles( FASTWP_SIMA_URI . '/assets/css',
    array(
        'assets',
        'main',
        'wp',
        'admin'
    )
);

fastwp_sima_core\main::add_styles( 'https://fonts.googleapis.com/css?family=',
    array(
        'Yantramanav:400,500'
    ),
    true,
    'google-fonts'
);

fastwp_sima_core\main::add_admin_styles( FASTWP_SIMA_URI . '/assets/css',
    array(
        'admin'
    )
);

/*** List of the javascript files used in Sima Theme ***/

fastwp_sima_core\main::add_scripts( FASTWP_SIMA_URI  . '/assets/js',
    array(
        'isotope',
        'waitforimages',
        'magnificpopup',
        'owlcarousel',
        'easing',
        'fitvids',
        'main'
    )
);

if( fastwp_sima_theme\utils::get_option( 'fwp_smoothscroll' ) ) {
    fastwp_sima_core\main::add_scripts( FASTWP_SIMA_URI  . '/assets/js',
        array(
            'smoothscroll'
        )
    );
}

if( fastwp_sima_theme\utils::get_option( 'fwp_gmap_key' ) !== '' ) {
    fastwp_sima_core\main::add_scripts( FASTWP_SIMA_URI  . '/assets/js',
        array(
            'custom'
        )
    );

    fastwp_sima_core\main::add_scripts( '//maps.googleapis.com/maps/api/js?key=' . fastwp_sima_theme\utils::get_option( 'fwp_gmap_key' ) );
}

fastwp_sima_core\main::add_script_deps( 'isotope', array( 'jquery' ) );

/*** List of required plugins ***/

fastwp_sima_core\tgmpa::add_plugin( 'contact-form-7',
    array(
        'name'      => 'Contact form 7',
        'required'  => false
    )
);

fastwp_sima_core\tgmpa::add_plugin( 'functionality-for-sima-theme',
    array(
        'name'      => 'Sima Theme Functionality',
        'source'    => FASTWP_SIMA_DIR . '/' . FASTWP_SIMA_FRAMEWORK_DIR . '/plugins/functionality-for-sima-theme.zip',
        'required'  => false
    )
);

fastwp_sima_core\tgmpa::add_plugin( 'jscomposer',
    array(
        'name'      => 'Page Builder (formerly Visual Composer)',
        'source'    => FASTWP_SIMA_DIR . '/' . FASTWP_SIMA_FRAMEWORK_DIR . '/plugins/js_composer.zip',
        'required'  => false
    )
);

fastwp_sima_core\tgmpa::add_plugin( 'fastwp-redux-sima-extension',
    array(
        'name'      => 'Redux Theme Options for Sima Theme',
        'source'    => FASTWP_SIMA_DIR . '/' . FASTWP_SIMA_FRAMEWORK_DIR . '/plugins/fastwp-redux-sima-extension.zip',
        'required'  => false
    )
);

/*** Add widget areas ***/

fastwp_sima_core\main::add_widget_area( 'sidebar-1', esc_html__( 'Sima Widgets', 'sima' ),
    array(
        'description'   => esc_html__( 'Widgets used in Sima theme', 'sima' ),
    )
);

/*** Customizer ***/

add_action( 'customize_register', array( 'fastwp_sima_customizer\customizer', 'register' ), 1 );

/*** Visual composer settings ***/

add_filter( 'vc_shortcodes_css_class', array( 'fastwp_sima_theme\filters', 'custom_css_classes_for_vc' ), 10, 2 );
add_action( 'init', array( 'fastwp_sima_theme\filters', 'params_for_vc' ), 10, 2 );

/*** Custom Menu ***/

new fastwp_sima_core\menu_admin;

if( fastwp_sima_theme\utils::get_option( 'fwp_theme_layout' ) == 'white' ) {
    fastwp_sima_theme\filters::add_body_class( 'light-navigation' );
}

?>
